@@ -91,7 +91,7 @@ void build_designmatrix_rv(network *dag,datamatrix *obsdata, double priormean, d
     for(k=0;k<dag->numNodes+3;k++){gsl_matrix_set(dag->modes,nodeid,k,DBL_MAX);} /** initialise row to DBL_MAX n.b. +2 here is need in fitabn.R part**/
     gsl_matrix_set(dag->modes,nodeid,0,1);/** the intercept term - always have an intercept - but not in dag.m definition */  
     for(k=0;k<numparents;k++){gsl_matrix_set(dag->modes,nodeid,gsl_vector_int_get(parentindexes,k)+1,1);} /** offset is 1 due to intercept */
-  gsl_matrix_set(dag->modes,nodeid,dag->numNodes+2,1);/** the group level precision term put at end of other params */ 
+  gsl_matrix_set(dag->modes,nodeid,dag->numNodes+1,1);/** the group level precision term put at end of other params */ 
  }
   /** ****************************************************************************************************/
   
@@ -670,7 +670,7 @@ double g_outer_single (double x, void *params)
   
   tau=gsl_vector_get(betaincTau,n_betas);/** extract the tau-precision from *beta - last entry */
   /*Rprintf("tau single=%f\n",tau);*/
-  if(tau<=0){/*Rprintf("negative tau in g_outer_single()\n");*/
+  if(tau<=0.0){/*Rprintf("negative tau in g_outer_single()\n");*/
   gsl_vector_set(betaincTau,fixed_beta,copyBeta);/** reset fixed parameter back again since changed in memory **/
   return(GSL_NAN);}/*((struct fnparams *) params)->tau_negFlag=1;Rprintf("=>%d\n",((struct fnparams *) params)->tau_negFlag);error("");}*/
   
